@@ -48,8 +48,13 @@
 #    else
 #      define __WORDSIZE	64
 #    endif
-#  else
-#    error cannot figure __WORDSIZE
+#  else						/* From FreeBSD 9.1 stdint.h */
+#    if defined(UINTPTR_MAX) && defined(UINT64_MAX) && \
+	(UINTPTR_MAX == UINT64_MAX)
+#      define __WORDSIZE	64
+#    else
+#      define __WORDSIZE	32
+#    endif
 #  endif
 #endif
 #ifndef __LITTLE_ENDIAN
@@ -946,6 +951,14 @@ extern jit_node_t *_jit_new_node_pwf(jit_state_t*, jit_code_t,
 extern jit_node_t *_jit_new_node_pwd(jit_state_t*, jit_code_t,
 				     jit_pointer_t, jit_word_t, jit_float64_t);
 
+#define jit_callee_save_p(u)		_jit_callee_save_p(_jit,u)
+extern jit_bool_t _jit_callee_save_p(jit_state_t*, jit_int32_t);
+#define jit_pointer_p(u)		_jit_pointer_p(_jit,u)
+extern jit_bool_t _jit_pointer_p(jit_state_t*,jit_pointer_t);
+
+#define jit_get_note(n,u,v,w)	_jit_get_note(_jit,n,u,v,w)
+extern jit_bool_t _jit_get_note(jit_state_t*,jit_pointer_t,char**,char**,int*);
+
 #define jit_disassemble()		_jit_disassemble(_jit)
 extern void _jit_disassemble(jit_state_t*);
 
