@@ -44,14 +44,32 @@ typedef enum {
 #define jit_v_num()		8
 #define jit_arg_f_reg_p(i)	((i) >= 0 && (i) < 4)
 #define jit_f(i)		(_F0 + (i))
-#define jit_f_num()		14
+#if NEW_ABI
+#  define jit_f_num()		6
+#else
+#  define jit_f_num()		8
+#endif
     _AT,
 #define JIT_R0			_V0
 #define JIT_R1			_V1
 #if NEW_ABI
 #  define JIT_R2		_T4
+#  define JIT_R3		_T5
+#  define JIT_R4		_T6
+#  define JIT_R5		_T7
+#  define JIT_R6		_T8
+#  define JIT_R7		_T9
 #else
 #  define JIT_R2		_T0
+#  define JIT_R3		_T1
+#  define JIT_R4		_T2
+#  define JIT_R5		_T3
+#  define JIT_R6		_T4
+#  define JIT_R7		_T5
+#  define JIT_R8		_T6
+#  define JIT_R9		_T7
+#  define JIT_R10		_T8
+#  define JIT_R11		_T9
 #endif
     _V0, _V1,
 #if !NEW_ABI
@@ -61,6 +79,11 @@ typedef enum {
 #define JIT_V0			_S0
 #define JIT_V1			_S1
 #define JIT_V2			_S2
+#define JIT_V3			_S3
+#define JIT_V4			_S4
+#define JIT_V5			_S5
+#define JIT_V6			_S6
+#define JIT_V7			_S7
     _S0, _S1, _S2, _S3, _S4, _S5, _S6, _S7,
     _ZERO, _K0, _K1, _RA,
     _GP,
@@ -76,6 +99,10 @@ typedef enum {
 #define JIT_F3			_F6
 #define JIT_F4			_F8
 #define JIT_F5			_F10
+#if !NEW_ABI
+#  define JIT_F6		_F16
+#  define JIT_F7		_F18
+#endif
     _F0, _F2, _F4, _F6, _F8, _F10,
     /* callee save float registers */
 #if !NEW_ABI
