@@ -396,6 +396,8 @@ struct jit_compiler {
 	jit_uint8_t	 *base;
     } note;
 #if __arm__
+    /* prevent using thumb instructions that set flags? */
+    jit_uint32_t	  no_set_flags : 1;
 #  if DISASSEMBLER
     struct {
 	jit_data_info_t	 *ptr;
@@ -430,8 +432,14 @@ struct jit_compiler {
     } prolog;
     jit_bool_t		  jump;
 #endif
-    /* global flag for code buffer heuristic size computation */
+#if GET_JIT_SIZE
+    /* Temporary storage to calculate instructions length */
+    jit_word_t		  size;
+    /* Global flag for code buffer heuristic size computation */
     jit_word_t		  mult;
+    /* Pointer to code to prevent miscalculation if reallocating buffer */
+    jit_uint8_t		 *cptr;
+#endif
 };
 
 #define _jitc				_jit->comp
@@ -548,8 +556,6 @@ extern void jit_init_note(void);
 extern void jit_finish_note(void);
 #define jit_set_note(n,u,v,w)	_jit_set_note(_jit, n, u, v, w)
 extern void _jit_set_note(jit_state_t*, jit_note_t*, char*, int, jit_int32_t);
-#define jit_get_note(n,u,v,w)	_jit_get_note(_jit, n, u, v, w)
-extern jit_bool_t _jit_get_note(jit_state_t*,jit_uint8_t*,char**,char**,int*);
 #define jit_annotate()		_jit_annotate(_jit)
 extern void _jit_annotate(jit_state_t*);
 
@@ -557,13 +563,26 @@ extern void jit_alloc(jit_pointer_t*, jit_word_t);
 extern void jit_realloc(jit_pointer_t*, jit_word_t, jit_word_t);
 void jit_free(jit_pointer_t*);
 
-#if HAVE_MREMAP
-#  define jit_remap()		_jit_remap(_jit)
-extern jit_bool_t _jit_remap(jit_state_t*);
+extern void jit_init_size(void);
+extern void jit_finish_size(void);
+
+#if GET_JIT_SIZE
+#  define jit_size_prepare()		_jit_size_prepare(_jit)
+extern void
+_jit_size_prepare(jit_state_t*);
+
+#  define jit_size_collect(node)	_jit_size_collect(_jit, node)
+extern void
+_jit_size_collect(jit_state_t*, jit_node_t*);
 #else
-#  define jit_remap()		0
+#  define jit_get_size()		_jit_get_size(_jit)
+extern jit_word_t
+_jit_get_size(jit_state_t*);
 #endif
 
+extern jit_word_t
+jit_get_max_instr(void);
+
 /*
  * Externs
  */
