@@ -42,6 +42,11 @@ typedef enum {
 #define JIT_V0			_L0
 #define JIT_V1			_L1
 #define JIT_V2			_L2
+#define JIT_V3			_L3
+#define JIT_V4			_L4
+#define JIT_V5			_L5
+#define JIT_V6			_L6
+#define JIT_V7			_L7
     _G0, _G1, _G2, _G3, _G4, _G5, _G6, _G7,
     _O0, _O1, _O2, _O3, _O4, _O5, _SP, _O7,
     _L0, _L1, _L2, _L3, _L4, _L5, _L6, _L7,
@@ -52,6 +57,8 @@ typedef enum {
 #define JIT_F3			_F6
 #define JIT_F4			_F8
 #define JIT_F5			_F10
+#define JIT_F6			_F12
+#define JIT_F7			_F14
     _F0, _F1,  _F2,  _F3,  _F4,  _F5,  _F6,  _F7,
     _F8, _F9, _F10, _F11, _F12, _F13, _F14, _F15,
 #define JIT_NOREG		_NOREG
