@@ -77,7 +77,6 @@ extern void __clear_cache(void *, void *);
  * Initialization
  */
 jit_cpu_t		jit_cpu;
-jit_flags_t		jit_flags;
 jit_register_t		_rvs[] = {
     { rc(gpr) | 0x0c,			"ip" },
     { rc(sav) | rc(gpr) | 0x04,		"r4" },
@@ -810,6 +809,7 @@ _emit_code(jit_state_t *_jit)
     } undo;
 
     _jitc->function = NULL;
+    _jitc->thumb = 0;
 
     jit_reglive_setup();
 
@@ -1026,7 +1026,7 @@ _emit_code(jit_state_t *_jit)
 		}							\
 		break
     for (node = _jitc->head; node; node = node->next) {
-	if (_jit->pc.uc >= _jitc->code.end && !jit_remap())
+	if (_jit->pc.uc >= _jitc->code.end)
 	    return (NULL);
 
 	value = jit_classify(node->code);
