@@ -83,47 +83,48 @@ jit_register_t		_rvs[] = {
     { rc(arg)|36,	 "r36" },	{ rc(arg)|37,		"r37" },
     { rc(arg)|38,	 "r38" },	{ rc(arg)|39,		"r39" },
     /* JIT_R0-JIT_V3 */
-    { rc(gpr)|40,	 "r40" },	{ rc(gpr)|41,		"r41" },
-    { rc(gpr)|42,	 "r42" },	{ rc(gpr)|43,		"r43" },
-    { rc(gpr)|44,	 "r44" },	{ rc(gpr)|45,		"r45" },
-    { rc(gpr)|46,	 "r46" },	{ rc(gpr)|47,		"r47" },
+    { rc(gpr)|rc(sav)|40, "r40" },	{ rc(gpr)|rc(sav)|41,	"r41" },
+    { rc(gpr)|rc(sav)|42, "r42" },	{ rc(gpr)|rc(sav)|43,	"r43" },
+    { rc(gpr)|rc(sav)|44, "r44" },	{ rc(gpr)|rc(sav)|45,	"r45" },
+    { rc(gpr)|rc(sav)|46, "r46" },	{ rc(gpr)|rc(sav)|47,	"r47" },
     /* Temporaries/locals */
-    { rc(gpr)|48,	 "r48" },	{ rc(gpr)|49,		"r49" },
-    { rc(gpr)|50,	 "r50" },	{ rc(gpr)|51,		"r51" },
-    { rc(gpr)|52,	 "r52" },	{ rc(gpr)|53,		"r53" },
-    { rc(gpr)|54,	 "r54" },	{ rc(gpr)|55,		"r55" },
-    { rc(gpr)|56,	 "r56" },	{ rc(gpr)|57,		"r57" },
-    { rc(gpr)|58,	 "r58" },	{ rc(gpr)|59,		"r59" },
-    { rc(gpr)|60,	 "r60" },	{ rc(gpr)|61,		"r61" },
-    { rc(gpr)|62,	 "r62" },	{ rc(gpr)|63,		"r63" },
-    { rc(gpr)|64,	 "r64" },	{ rc(gpr)|65,		"r65" },
-    { rc(gpr)|66,	 "r66" },	{ rc(gpr)|67,		"r67" },
-    { rc(gpr)|68,	 "r68" },	{ rc(gpr)|69,		"r69" },
-    { rc(gpr)|70,	 "r70" },	{ rc(gpr)|71,		"r71" },
-    { rc(gpr)|72,	 "r72" },	{ rc(gpr)|73,		"r73" },
-    { rc(gpr)|74,	 "r74" },	{ rc(gpr)|75,		"r75" },
-    { rc(gpr)|76,	 "r76" },	{ rc(gpr)|77,		"r77" },
-    { rc(gpr)|78,	 "r78" },	{ rc(gpr)|79,		"r79" },
-    { rc(gpr)|80,	 "r80" },	{ rc(gpr)|81,		"r81" },
-    { rc(gpr)|82,	 "r82" },	{ rc(gpr)|83,		"r83" },
-    { rc(gpr)|84,	 "r84" },	{ rc(gpr)|85,		"r85" },
-    { rc(gpr)|86,	 "r86" },	{ rc(gpr)|87,		"r87" },
-    { rc(gpr)|88,	 "r88" },	{ rc(gpr)|89,		"r89" },
-    { rc(gpr)|90,	 "r90" },	{ rc(gpr)|91,		"r91" },
-    { rc(gpr)|92,	 "r92" },	{ rc(gpr)|93,		"r93" },
-    { rc(gpr)|94,	 "r94" },	{ rc(gpr)|95,		"r95" },
-    { rc(gpr)|96,	 "r96" },	{ rc(gpr)|97,		"r97" },
-    { rc(gpr)|98,	 "r98" },	{ rc(gpr)|99,		"r99" },
-    { rc(gpr)|100,	 "r100"},	{ rc(gpr)|101,		"r101"},
-    { rc(gpr)|102,	 "r102"},	{ rc(gpr)|103,		"r103"},
-    { rc(gpr)|104,	 "r104"},	{ rc(gpr)|105,		"r105"},
-    { rc(gpr)|106,	 "r106"},	{ rc(gpr)|107,		"r107"},
-    { rc(gpr)|108,	 "r108"},	{ rc(gpr)|109,		"r109"},
-    { rc(gpr)|110,	 "r110"},	{ rc(gpr)|111,		"r111"},
-    { rc(gpr)|112,	 "r112"},	{ rc(gpr)|113,		"r113"},
-    { rc(gpr)|114,	 "r114"},	{ rc(gpr)|115,		"r115"},
-    /* Do not enable these because no matter what, want 12 free registers,
-     * 4 for prolog and epilog and 8 for outgoing arguments */
+    { rc(gpr)|rc(sav)|48, "r48" },	{ rc(gpr)|rc(sav)|49,	"r49" },
+    { rc(gpr)|rc(sav)|50, "r50" },	{ rc(gpr)|rc(sav)|51,	"r51" },
+    { rc(gpr)|rc(sav)|52, "r52" },	{ rc(gpr)|rc(sav)|53,	"r53" },
+    { rc(gpr)|rc(sav)|54, "r54" },	{ rc(gpr)|rc(sav)|55,	"r55" },
+    { rc(gpr)|rc(sav)|56, "r56" },	{ rc(gpr)|rc(sav)|57,	"r57" },
+    { rc(gpr)|rc(sav)|58, "r58" },	{ rc(gpr)|rc(sav)|59,	"r59" },
+    { rc(gpr)|rc(sav)|60, "r60" },	{ rc(gpr)|rc(sav)|61,	"r61" },
+    { rc(gpr)|rc(sav)|62, "r62" },	{ rc(gpr)|rc(sav)|63,	"r63" },
+    { rc(gpr)|rc(sav)|64, "r64" },	{ rc(gpr)|rc(sav)|65,	"r65" },
+    { rc(gpr)|rc(sav)|66, "r66" },	{ rc(gpr)|rc(sav)|67,	"r67" },
+    { rc(gpr)|rc(sav)|68, "r68" },	{ rc(gpr)|rc(sav)|69,	"r69" },
+    { rc(gpr)|rc(sav)|70, "r70" },	{ rc(gpr)|rc(sav)|71,	"r71" },
+    { rc(gpr)|rc(sav)|72, "r72" },	{ rc(gpr)|rc(sav)|73,	"r73" },
+    { rc(gpr)|rc(sav)|74, "r74" },	{ rc(gpr)|rc(sav)|75,	"r75" },
+    { rc(gpr)|rc(sav)|76, "r76" },	{ rc(gpr)|rc(sav)|77,	"r77" },
+    { rc(gpr)|rc(sav)|78, "r78" },	{ rc(gpr)|rc(sav)|79,	"r79" },
+    { rc(gpr)|rc(sav)|80, "r80" },	{ rc(gpr)|rc(sav)|81,	"r81" },
+    { rc(gpr)|rc(sav)|82, "r82" },	{ rc(gpr)|rc(sav)|83,	"r83" },
+    { rc(gpr)|rc(sav)|84, "r84" },	{ rc(gpr)|rc(sav)|85,	"r85" },
+    { rc(gpr)|rc(sav)|86, "r86" },	{ rc(gpr)|rc(sav)|87,	"r87" },
+    { rc(gpr)|rc(sav)|88, "r88" },	{ rc(gpr)|rc(sav)|89,	"r89" },
+    { rc(gpr)|rc(sav)|90, "r90" },	{ rc(gpr)|rc(sav)|91,	"r91" },
+    { rc(gpr)|rc(sav)|92, "r92" },	{ rc(gpr)|rc(sav)|93,	"r93" },
+    { rc(gpr)|rc(sav)|94, "r94" },	{ rc(gpr)|rc(sav)|95,	"r95" },
+    { rc(gpr)|rc(sav)|96, "r96" },	{ rc(gpr)|rc(sav)|97,	"r97" },
+    { rc(gpr)|rc(sav)|98, "r98" },	{ rc(gpr)|rc(sav)|99,	"r99" },
+    { rc(gpr)|rc(sav)|100,"r100"},	{ rc(gpr)|rc(sav)|101,	"r101"},
+    { rc(gpr)|rc(sav)|102,"r102"},	{ rc(gpr)|rc(sav)|103,	"r103"},
+    { rc(gpr)|rc(sav)|104,"r104"},	{ rc(gpr)|rc(sav)|105,	"r105"},
+    { rc(gpr)|rc(sav)|106,"r106"},	{ rc(gpr)|rc(sav)|107,	"r107"},
+    { rc(gpr)|rc(sav)|108,"r108"},	{ rc(gpr)|rc(sav)|109,	"r109"},
+    { rc(gpr)|rc(sav)|110,"r110"},	{ rc(gpr)|rc(sav)|111,	"r111"},
+    { rc(gpr)|rc(sav)|112,"r112"},	{ rc(gpr)|rc(sav)|113,	"r113"},
+    { rc(gpr)|rc(sav)|114,"r114"},
+    /* Do not enable these because no matter what, want 13 free registers,
+     * 5 for prolog and epilog and 8 for outgoing arguments */
+    { 115,		 "r115"},
     { 116,		 "r116"},	{ 117,			"r117"},
     { 118,		 "r118"},	{ 119,			"r119"},
     { 120,		 "r120"},	{ 121,			"r121"},
@@ -735,7 +736,6 @@ _jit_retval_d(jit_state_t *_jit, jit_int32_t r0)
 jit_pointer_t
 _emit_code(jit_state_t *_jit)
 {
-    jit_uint8_t		*end;
     jit_node_t		*node;
     jit_node_t		*temp;
     jit_word_t		 word;
@@ -763,7 +763,8 @@ _emit_code(jit_state_t *_jit)
 
     undo.prolog_offset = 0;
     /* code may start with a jump so add an initial function descriptor */
-    il(_jit->pc.w + 16);	/* addr */
+    word = _jit->pc.w + 16;
+    il(word);			/* addr */
     il(0);			/* gp */
 #define case_rr(name, type)						\
 	    case jit_code_##name##r##type:				\
@@ -848,11 +849,13 @@ _emit_code(jit_state_t *_jit)
 		    patch(word, node);					\
 		}							\
 		break
+#if GET_JIT_SIZE
     /* default of 64 bytes is too low for some possible
      * quite long code generation sequences, e.g. qdivi */
-    end = _jit->code.ptr + _jit->code.length - 4096;
+    _jitc->code.end = _jit->code.ptr + _jit->code.length - 4096;
+#endif
     for (node = _jitc->head; node; node = node->next) {
-	if (_jit->pc.uc >= end && !jit_remap())
+	if (_jit->pc.uc >= _jitc->code.end)
 	    return (NULL);
 
 	value = jit_classify(node->code);
@@ -1264,7 +1267,8 @@ _emit_code(jit_state_t *_jit)
 		    }
 		    _jitc->prolog.ptr[_jitc->prolog.offset++] = _jit->pc.w;
 		    /* function descriptor */
-		    il(_jit->pc.w + 16);	/* addr */
+		    word = _jit->pc.w + 16;
+		    il(word);			/* addr */
 		    il(0);			/* gp */
 		}
 		prolog(node);
