@@ -180,12 +180,14 @@ init_jit(char *progname)
     jit_progname = progname;
     jit_get_cpu();
     jit_init_debug();
+    jit_init_size();
 }
 
 void
 finish_jit(void)
 {
     jit_finish_debug();
+    jit_finish_size();
 }
 
 jit_int32_t
@@ -330,6 +332,20 @@ _jit_unget_reg(jit_state_t *_jit, jit_int32_t regno)
     jit_regset_clrbit(&_jitc->regarg, regno);
 }
 
+jit_bool_t
+_jit_callee_save_p(jit_state_t *_jit, jit_int32_t regno)
+{
+    assert(regno >= 0 && regno < JIT_NOREG);
+    return (!!(_rvs[regno].spec & jit_class_sav));
+}
+
+extern jit_bool_t
+_jit_pointer_p(jit_state_t *_jit, jit_pointer_t address)
+{
+    return ((jit_uint8_t *)address >= _jit->code.ptr &&
+	    (jit_word_t)address < _jit->pc.w);
+}
+
 #if __ia64__
 void
 jit_regset_com(jit_regset_t *u, jit_regset_t *v)
@@ -1630,6 +1646,9 @@ _jit_reglive(jit_state_t *_jit, jit_node_t *node)
 void
 _jit_regarg_set(jit_state_t *_jit, jit_node_t *node, jit_int32_t value)
 {
+#if GET_JIT_SIZE
+    jit_size_prepare();
+#endif
     if (value & jit_cc_a0_reg) {
 	if (value & jit_cc_a0_rlh) {
 	    jit_regset_setbit(&_jitc->regarg, jit_regno(node->u.q.l));
@@ -1647,6 +1666,9 @@ _jit_regarg_set(jit_state_t *_jit, jit_node_t *node, jit_int32_t value)
 void
 _jit_regarg_clr(jit_state_t *_jit, jit_node_t *node, jit_int32_t value)
 {
+#if GET_JIT_SIZE
+    jit_size_collect(node);
+#endif
     if (value & jit_cc_a0_reg) {
 	if (value & jit_cc_a0_rlh) {
 	    jit_regset_clrbit(&_jitc->regarg, jit_regno(node->u.q.l));
@@ -1676,12 +1698,15 @@ _jit_emit(jit_state_t *_jit)
 	jit_epilog();
     jit_optimize();
 
-    /* Heuristic to guess code buffer size */
-    _jitc->mult = 4;
-
     _jitc->emit = 1;
 
+#if GET_JIT_SIZE
+    /* Heuristic to guess code buffer size */
+    _jitc->mult = 4;
     _jit->code.length = _jitc->pool.length * 1024 * _jitc->mult;
+#else
+    _jit->code.length = jit_get_size();
+#endif
 
 #if defined(__sgi)
     mmap_fd = open("/dev/zero", O_RDWR);
@@ -1690,7 +1715,8 @@ _jit_emit(jit_state_t *_jit)
 			  PROT_EXEC | PROT_READ | PROT_WRITE,
 			  MAP_PRIVATE | MAP_ANON, mmap_fd, 0);
     assert(_jit->code.ptr != MAP_FAILED);
-    _jitc->code.end = _jit->code.ptr + _jit->code.length - 64;
+    _jitc->code.end = _jit->code.ptr + _jit->code.length -
+	jit_get_max_instr();
     _jit->pc.uc = _jit->code.ptr;
 
     for (;;) {
@@ -1701,16 +1727,26 @@ _jit_emit(jit_state_t *_jit)
 		     node->code == jit_code_epilog))
 		    node->flag &= ~jit_flag_patch;
 	    }
+#if GET_JIT_SIZE
 	    ++_jitc->mult;
 	    length = _jitc->pool.length * 1024 * _jitc->mult;
+#else
+	    /* Should only happen on very special cases */
+	    length = _jit->code.length + 4096;
+#endif
 
 #if !HAVE_MREMAP
 	    munmap(_jit->code.ptr, _jit->code.length);
 #endif
 
 #if HAVE_MREMAP
+#  if __NetBSD__
+	    _jit->code.ptr = mremap(_jit->code.ptr, _jit->code.length,
+				    _jit->code.ptr, length, 0);
+#  else
 	    _jit->code.ptr = mremap(_jit->code.ptr, _jit->code.length,
 				    length, MREMAP_MAYMOVE, NULL);
+#  endif
 #else
 	    _jit->code.ptr = mmap(NULL, length,
 				  PROT_EXEC | PROT_READ | PROT_WRITE,
@@ -1719,7 +1755,8 @@ _jit_emit(jit_state_t *_jit)
 
 	    assert(_jit->code.ptr != MAP_FAILED);
 	    _jit->code.length = length;
-	    _jitc->code.end = _jit->code.ptr + _jit->code.length - 64;
+	    _jitc->code.end = _jit->code.ptr + _jit->code.length -
+		jit_get_max_instr();
 	    _jit->pc.uc = _jit->code.ptr;
 	    _jitc->patches.offset = 0;
 	}
