@@ -19,7 +19,7 @@ __author_email__ = "pytorch@lightning.ai"
 __license__ = "Apache-2.0"
 __copyright__ = f"Copyright (c) 2018-{time.strftime('%Y')}, {__author__}."
 __homepage__ = "https://github.com/Lightning-AI/lightning"
-__docs_url__ = "https://pytorch-lightning.readthedocs.io/en/stable/"
+__docs_url__ = "https://lightning.ai/docs/pytorch/stable/"
 # this has to be simple string, see: https://github.com/pypa/twine/issues/522
 __docs__ = (
     "Use Lightning Apps to build everything from production-ready, multi-cloud ML systems to simple research demos."
