@@ -1,3 +1,17 @@
+# Copyright The Lightning AI team.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import abc
 import inspect
 import os
@@ -64,6 +78,8 @@ class ModelInferenceAPI(LightningWork, abc.ABC):
         self.workers = workers
         self._model = None
 
+        self.ready = False
+
     @property
     def model(self):
         return self._model
@@ -108,9 +124,11 @@ class ModelInferenceAPI(LightningWork, abc.ABC):
                 "serve:fastapi_service",
             ]
             process = subprocess.Popen(command, env=env, cwd=os.path.dirname(__file__))
+            self.ready = True
             process.wait()
         else:
             self._populate_app(fastapi_service)
+            self.ready = True
             self._launch_server(fastapi_service)
 
     def _populate_app(self, fastapi_service: FastAPI):
