@@ -13,6 +13,7 @@
 # limitations under the License.
 
 import abc
+from typing import Any
 
 
 class BaseType(abc.ABCMeta):
@@ -23,7 +24,7 @@ class BaseType(abc.ABCMeta):
         """Serialize the incoming data to send it through the network."""
 
     @abc.abstractmethod
-    def deserialize(self, *args, **kwargs):  # pragma: no cover
+    def deserialize(self, *args: Any, **kwargs: Any):  # pragma: no cover
         """Take the inputs from the network and deserilize/convert them them.
 
         Output from this method will go to the exposed method as arguments.
