@@ -1,3 +1,17 @@
+# Copyright The Lightning AI team.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import os
 import pathlib
 import shutil
@@ -11,7 +25,6 @@ from lightning.app.utilities.component import _is_flow_context
 
 
 class Drive:
-
     __IDENTIFIER__ = "__drive__"
     __PROTOCOLS__ = ["lit://"]
 
@@ -220,7 +233,7 @@ class Drive:
             "protocol": self.protocol,
             "allow_duplicates": self.allow_duplicates,
             "component_name": self.component_name,
-            "root_folder": self.root_folder,
+            "root_folder": str(self.root_folder),
         }
 
     @classmethod
