@@ -2,8 +2,14 @@
 import logging
 import os
 
-from lightning.fabric.__about__ import *  # noqa: F401, F403
-from lightning.fabric.__version__ import version as __version__  # noqa: F401
+from lightning_utilities.core.imports import package_available
+
+if os.path.isfile(os.path.join(os.path.dirname(__file__), "__about__.py")):
+    from lightning.fabric.__about__ import *  # noqa: F401, F403
+if os.path.isfile(os.path.join(os.path.dirname(__file__), "__version__.py")):
+    from lightning.fabric.__version__ import version as __version__
+elif package_available("lightning"):
+    from lightning import __version__  # noqa: F401
 
 _root_logger = logging.getLogger()
 _logger = logging.getLogger(__name__)
@@ -22,8 +28,9 @@ os.environ["PYTORCH_NVML_BASED_CUDA_CHECK"] = "1"
 
 from lightning.fabric.fabric import Fabric  # noqa: E402
 from lightning.fabric.utilities.seed import seed_everything  # noqa: E402
+from lightning.fabric.wrappers import is_wrapped  # noqa: E402
 
-__all__ = ["Fabric", "seed_everything"]
+__all__ = ["Fabric", "seed_everything", "is_wrapped"]
 
 # for compatibility with namespace packages
 __import__("pkg_resources").declare_namespace(__name__)
