@@ -25,6 +25,9 @@ from typing import Any, Dict
 import lightning.pytorch as pl
 from lightning.pytorch.callbacks.callback import Callback
 from lightning.pytorch.utilities.exceptions import MisconfigurationException
+from lightning.pytorch.utilities.imports import _LIGHTNING_COLOSSALAI_AVAILABLE
+from lightning.pytorch.utilities.model_helpers import is_overridden
+from lightning.pytorch.utilities.rank_zero import rank_zero_warn
 
 
 class GradientAccumulationScheduler(Callback):
@@ -58,9 +61,6 @@ class GradientAccumulationScheduler(Callback):
         # because epoch (key) should be zero-indexed.
         >>> accumulator = GradientAccumulationScheduler(scheduling={4: 2})
         >>> trainer = Trainer(callbacks=[accumulator])
-
-        # alternatively, pass the scheduling dict directly to the Trainer
-        >>> trainer = Trainer(accumulate_grad_batches={4: 2})
     """
 
     def __init__(self, scheduling: Dict[int, int]):
@@ -82,7 +82,7 @@ class GradientAccumulationScheduler(Callback):
         minimal_epoch = min(scheduling.keys())
         if minimal_epoch < 0:
             raise IndexError(f"Epochs indexing from 1, epoch {minimal_epoch} cannot be interpreted correct")
-        if minimal_epoch != 0:  # if user didnt define first epoch accumulation factor
+        if minimal_epoch != 0:  # if user didn't define first epoch accumulation factor
             scheduling.update({0: 1})
 
         self.scheduling = scheduling
@@ -99,5 +99,53 @@ class GradientAccumulationScheduler(Callback):
                 break
         return accumulate_grad_batches
 
+    def on_train_start(self, trainer: "pl.Trainer", pl_module: "pl.LightningModule") -> None:
+        """Performns a configuration validation before training starts and raises errors for incompatible
+        settings."""
+
+        if not pl_module.automatic_optimization:
+            raise RuntimeError(
+                """Automatic gradient accumulation and the `GradientAccumulationScheduler` is not supported for
+                manual optimization. Please remove the callback or switch to automatic optimization."""
+            )
+
+        overridden_optimizer_step = is_overridden("optimizer_step", pl_module)
+        overridden_optimizer_zero_grad = is_overridden("optimizer_zero_grad", pl_module)
+        going_to_accumulate_grad_batches = self.going_to_accumulate_grad_batches()
+        has_overridden_optimization_functions = overridden_optimizer_step or overridden_optimizer_zero_grad
+        if has_overridden_optimization_functions and going_to_accumulate_grad_batches:
+            rank_zero_warn(
+                "When using `Trainer(accumulate_grad_batches != 1)` and overriding"
+                " `LightningModule.optimizer_{step,zero_grad}`, the hooks will not be called on every batch"
+                " (rather, they are called on every optimization step)."
+            )
+
+        # local import to avoid circular import
+        from lightning.pytorch.accelerators import IPUAccelerator
+        from lightning.pytorch.strategies import DeepSpeedStrategy
+
+        unsupported_accelerators = (IPUAccelerator,)
+        unsupported_strategies = [DeepSpeedStrategy]
+        if _LIGHTNING_COLOSSALAI_AVAILABLE:
+            from lightning_colossalai import ColossalAIStrategy
+
+            unsupported_strategies.append(ColossalAIStrategy)
+
+        if isinstance(trainer.accelerator, unsupported_accelerators):
+            raise RuntimeError(
+                f"The `{type(trainer.accelerator).__name__}` does not support `accumulate_grad_batches` changing"
+                " between epochs."
+            )
+        if isinstance(trainer.strategy, tuple(unsupported_strategies)):
+            raise RuntimeError(
+                f"The `{type(trainer.strategy).__name__}` does not support `accumulate_grad_batches` changing"
+                " between epochs."
+            )
+        if trainer.accumulate_grad_batches != 1:
+            raise ValueError(
+                "You have set `accumulate_grad_batches` and are using the `GradientAccumulationScheduler`"
+                " callback. Either remove `accumulate_grad_batches` from the Trainer or remove the callback."
+            )
+
     def on_train_epoch_start(self, trainer: "pl.Trainer", *_: Any) -> None:
         trainer.accumulate_grad_batches = self.get_accumulate_grad_batches(trainer.current_epoch)
