@@ -19,16 +19,16 @@ from typing import Any, cast, Dict, Optional, Union
 from lightning_utilities.core.imports import RequirementCache
 
 import lightning.pytorch as pl
-from lightning.pytorch.callbacks.progress.base import ProgressBarBase
+from lightning.pytorch.callbacks.progress.progress_bar import ProgressBar
 from lightning.pytorch.utilities.types import STEP_OUTPUT
 
-_RICH_AVAILABLE: bool = RequirementCache("rich>=10.2.2")
+_RICH_AVAILABLE = RequirementCache("rich>=10.2.2")
 
 if _RICH_AVAILABLE:
     from rich import get_console, reconfigure
     from rich.console import Console, RenderableType
     from rich.progress import BarColumn, Progress, ProgressColumn, Task, TaskID, TextColumn
-    from rich.progress_bar import ProgressBar
+    from rich.progress_bar import ProgressBar as _RichProgressBar
     from rich.style import Style
     from rich.text import Text
 
@@ -36,11 +36,11 @@ if _RICH_AVAILABLE:
         """Overrides ``BarColumn`` to provide support for dataloaders that do not define a size (infinite size)
         such as ``IterableDataset``."""
 
-        def render(self, task: "Task") -> ProgressBar:
+        def render(self, task: "Task") -> _RichProgressBar:
             """Gets a progress bar widget for a task."""
             assert task.total is not None
             assert task.remaining is not None
-            return ProgressBar(
+            return _RichProgressBar(
                 total=max(0, task.total),
                 completed=max(0, task.completed),
                 width=None if self.bar_width is None else max(1, self.bar_width),
@@ -156,7 +156,7 @@ if _RICH_AVAILABLE:
             if (
                 self._trainer.state.fn != "fit"
                 or self._trainer.sanity_checking
-                or self._trainer.progress_bar_callback.main_progress_bar_id != task.id
+                or self._trainer.progress_bar_callback.train_progress_bar_id != task.id
             ):
                 return Text()
             if self._trainer.training and task.id not in self._tasks:
@@ -204,7 +204,7 @@ class RichProgressBarTheme:
     metrics: Union[str, Style] = "white"
 
 
-class RichProgressBar(ProgressBarBase):
+class RichProgressBar(ProgressBar):
     """Create a progress bar with `rich text formatting <https://github.com/Textualize/rich>`_.
 
     Install it with pip:
@@ -256,7 +256,7 @@ class RichProgressBar(ProgressBarBase):
         self._console_kwargs = console_kwargs or {}
         self._enabled: bool = True
         self.progress: Optional[CustomProgress] = None
-        self.main_progress_bar_id: Optional["TaskID"]
+        self.train_progress_bar_id: Optional["TaskID"]
         self.val_sanity_progress_bar_id: Optional["TaskID"] = None
         self.val_progress_bar_id: Optional["TaskID"]
         self.test_progress_bar_id: Optional["TaskID"]
@@ -280,10 +280,10 @@ class RichProgressBar(ProgressBarBase):
         return not self.is_enabled
 
     @property
-    def main_progress_bar(self) -> Task:
+    def train_progress_bar(self) -> Task:
         assert self.progress is not None
-        assert self.main_progress_bar_id is not None
-        return self.progress.tasks[self.main_progress_bar_id]
+        assert self.train_progress_bar_id is not None
+        return self.progress.tasks[self.train_progress_bar_id]
 
     @property
     def val_sanity_check_bar(self) -> Task:
@@ -362,24 +362,29 @@ class RichProgressBar(ProgressBarBase):
     def on_train_epoch_start(self, trainer: "pl.Trainer", pl_module: "pl.LightningModule") -> None:
         if self.is_disabled:
             return
-        total_batches = self.total_batches_current_epoch
+        total_batches = self.total_train_batches
         train_description = self._get_train_description(trainer.current_epoch)
 
-        if self.main_progress_bar_id is not None and self._leave:
+        if self.train_progress_bar_id is not None and self._leave:
             self._stop_progress()
             self._init_progress(trainer)
         if self.progress is not None:
-            if self.main_progress_bar_id is None:
-                self.main_progress_bar_id = self._add_task(total_batches, train_description)
+            if self.train_progress_bar_id is None:
+                self.train_progress_bar_id = self._add_task(total_batches, train_description)
             else:
                 self.progress.reset(
-                    self.main_progress_bar_id, total=total_batches, description=train_description, visible=True
+                    self.train_progress_bar_id, total=total_batches, description=train_description, visible=True
                 )
 
         self.refresh()
 
     def on_validation_batch_start(
-        self, trainer: "pl.Trainer", pl_module: "pl.LightningModule", batch: Any, batch_idx: int, dataloader_idx: int
+        self,
+        trainer: "pl.Trainer",
+        pl_module: "pl.LightningModule",
+        batch: Any,
+        batch_idx: int,
+        dataloader_idx: int = 0,
     ) -> None:
         if self.is_disabled or not self.has_dataloader_changed(dataloader_idx):
             return
@@ -442,7 +447,12 @@ class RichProgressBar(ProgressBarBase):
         self.reset_dataloader_idx_tracker()
 
     def on_test_batch_start(
-        self, trainer: "pl.Trainer", pl_module: "pl.LightningModule", batch: Any, batch_idx: int, dataloader_idx: int
+        self,
+        trainer: "pl.Trainer",
+        pl_module: "pl.LightningModule",
+        batch: Any,
+        batch_idx: int,
+        dataloader_idx: int = 0,
     ) -> None:
         if self.is_disabled or not self.has_dataloader_changed(dataloader_idx):
             return
@@ -454,7 +464,12 @@ class RichProgressBar(ProgressBarBase):
         self.refresh()
 
     def on_predict_batch_start(
-        self, trainer: "pl.Trainer", pl_module: "pl.LightningModule", batch: Any, batch_idx: int, dataloader_idx: int
+        self,
+        trainer: "pl.Trainer",
+        pl_module: "pl.LightningModule",
+        batch: Any,
+        batch_idx: int,
+        dataloader_idx: int = 0,
     ) -> None:
         if self.is_disabled or not self.has_dataloader_changed(dataloader_idx):
             return
@@ -470,7 +485,7 @@ class RichProgressBar(ProgressBarBase):
     def on_train_batch_end(
         self, trainer: "pl.Trainer", pl_module: "pl.LightningModule", outputs: STEP_OUTPUT, batch: Any, batch_idx: int
     ) -> None:
-        self._update(self.main_progress_bar_id, self.train_batch_idx + self._val_processed)
+        self._update(self.train_progress_bar_id, batch_idx + 1)
         self._update_metrics(trainer, pl_module)
         self.refresh()
 
@@ -484,17 +499,14 @@ class RichProgressBar(ProgressBarBase):
         outputs: Optional[STEP_OUTPUT],
         batch: Any,
         batch_idx: int,
-        dataloader_idx: int,
+        dataloader_idx: int = 0,
     ) -> None:
         if self.is_disabled:
             return
         if trainer.sanity_checking:
-            self._update(self.val_sanity_progress_bar_id, self.val_batch_idx)
+            self._update(self.val_sanity_progress_bar_id, batch_idx + 1)
         elif self.val_progress_bar_id is not None:
-            # check to see if we should update the main training progress bar
-            if self.main_progress_bar_id is not None:
-                self._update(self.main_progress_bar_id, self.train_batch_idx + self._val_processed)
-            self._update(self.val_progress_bar_id, self.val_batch_idx)
+            self._update(self.val_progress_bar_id, batch_idx + 1)
         self.refresh()
 
     def on_test_batch_end(
@@ -504,12 +516,12 @@ class RichProgressBar(ProgressBarBase):
         outputs: Optional[STEP_OUTPUT],
         batch: Any,
         batch_idx: int,
-        dataloader_idx: int,
+        dataloader_idx: int = 0,
     ) -> None:
         if self.is_disabled:
             return
         assert self.test_progress_bar_id is not None
-        self._update(self.test_progress_bar_id, self.test_batch_idx)
+        self._update(self.test_progress_bar_id, batch_idx + 1)
         self.refresh()
 
     def on_predict_batch_end(
@@ -519,12 +531,12 @@ class RichProgressBar(ProgressBarBase):
         outputs: Any,
         batch: Any,
         batch_idx: int,
-        dataloader_idx: int,
+        dataloader_idx: int = 0,
     ) -> None:
         if self.is_disabled:
             return
         assert self.predict_progress_bar_id is not None
-        self._update(self.predict_progress_bar_id, self.predict_batch_idx)
+        self._update(self.predict_progress_bar_id, batch_idx + 1)
         self.refresh()
 
     def _get_train_description(self, current_epoch: int) -> str:
@@ -544,7 +556,7 @@ class RichProgressBar(ProgressBarBase):
             self._progress_stopped = True
 
     def _reset_progress_bar_ids(self) -> None:
-        self.main_progress_bar_id = None
+        self.train_progress_bar_id = None
         self.val_sanity_progress_bar_id = None
         self.val_progress_bar_id = None
         self.test_progress_bar_id = None
