@@ -13,7 +13,7 @@
 # limitations under the License.
 """Various hooks to be used in the Lightning code."""
 
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, Optional
 
 import torch
 from torch import Tensor
@@ -77,12 +77,12 @@ class ModelHooks:
         """Called in the training loop after the batch.
 
         Args:
-            outputs: The outputs of training_step_end(training_step(x))
+            outputs: The outputs of training_step(x)
             batch: The batched data as it is returned by the training DataLoader.
             batch_idx: the index of the batch
         """
 
-    def on_validation_batch_start(self, batch: Any, batch_idx: int, dataloader_idx: int) -> None:
+    def on_validation_batch_start(self, batch: Any, batch_idx: int, dataloader_idx: int = 0) -> None:
         """Called in the validation loop before anything happens for that batch.
 
         Args:
@@ -92,18 +92,18 @@ class ModelHooks:
         """
 
     def on_validation_batch_end(
-        self, outputs: Optional[STEP_OUTPUT], batch: Any, batch_idx: int, dataloader_idx: int
+        self, outputs: Optional[STEP_OUTPUT], batch: Any, batch_idx: int, dataloader_idx: int = 0
     ) -> None:
         """Called in the validation loop after the batch.
 
         Args:
-            outputs: The outputs of validation_step_end(validation_step(x))
+            outputs: The outputs of validation_step(x)
             batch: The batched data as it is returned by the validation DataLoader.
             batch_idx: the index of the batch
             dataloader_idx: the index of the dataloader
         """
 
-    def on_test_batch_start(self, batch: Any, batch_idx: int, dataloader_idx: int) -> None:
+    def on_test_batch_start(self, batch: Any, batch_idx: int, dataloader_idx: int = 0) -> None:
         """Called in the test loop before anything happens for that batch.
 
         Args:
@@ -113,18 +113,18 @@ class ModelHooks:
         """
 
     def on_test_batch_end(
-        self, outputs: Optional[STEP_OUTPUT], batch: Any, batch_idx: int, dataloader_idx: int
+        self, outputs: Optional[STEP_OUTPUT], batch: Any, batch_idx: int, dataloader_idx: int = 0
     ) -> None:
         """Called in the test loop after the batch.
 
         Args:
-            outputs: The outputs of test_step_end(test_step(x))
+            outputs: The outputs of test_step(x)
             batch: The batched data as it is returned by the test DataLoader.
             batch_idx: the index of the batch
             dataloader_idx: the index of the dataloader
         """
 
-    def on_predict_batch_start(self, batch: Any, batch_idx: int, dataloader_idx: int) -> None:
+    def on_predict_batch_start(self, batch: Any, batch_idx: int, dataloader_idx: int = 0) -> None:
         """Called in the predict loop before anything happens for that batch.
 
         Args:
@@ -133,12 +133,12 @@ class ModelHooks:
             dataloader_idx: the index of the dataloader
         """
 
-    def on_predict_batch_end(self, outputs: Optional[Any], batch: Any, batch_idx: int, dataloader_idx: int) -> None:
+    def on_predict_batch_end(self, outputs: Optional[Any], batch: Any, batch_idx: int, dataloader_idx: int = 0) -> None:
         """Called in the predict loop after the batch.
 
         Args:
-            outputs: The outputs of predict_step_end(test_step(x))
-            batch: The batched data as it is returned by the test DataLoader.
+            outputs: The outputs of predict_step(x)
+            batch: The batched data as it is returned by the prediction DataLoader.
             batch_idx: the index of the batch
             dataloader_idx: the index of the dataloader
         """
@@ -169,10 +169,27 @@ class ModelHooks:
     def on_train_epoch_end(self) -> None:
         """Called in the training loop at the very end of the epoch.
 
-        To access all batch outputs at the end of the epoch, either:
+        To access all batch outputs at the end of the epoch, you can cache step outputs as an attribute of the
+        :class:`~lightning.pytorch.LightningModule` and access them in this hook:
 
-        1. Implement `training_epoch_end` in the LightningModule OR
-        2. Cache data across steps on the attribute(s) of the `LightningModule` and access them in this hook
+        .. code-block:: python
+
+            class MyLightningModule(L.LightningModule):
+                def __init__(self):
+                    super().__init__()
+                    self.training_step_outputs = []
+
+                def training_step(self):
+                    loss = ...
+                    self.training_step_outputs.append(loss)
+                    return loss
+
+                def on_train_epoch_end(self):
+                    # do something with all training_step outputs, for example:
+                    epoch_mean = torch.stack(self.training_step_outputs).mean()
+                    self.log("training_epoch_mean", epoch_mean)
+                    # free up the memory
+                    self.training_step_outputs.clear()
         """
 
     def on_validation_epoch_start(self) -> None:
@@ -190,7 +207,7 @@ class ModelHooks:
     def on_predict_epoch_start(self) -> None:
         """Called at the beginning of predicting."""
 
-    def on_predict_epoch_end(self, results: List[Any]) -> None:
+    def on_predict_epoch_end(self) -> None:
         """Called at the end of predicting."""
 
     def on_before_zero_grad(self, optimizer: Optimizer) -> None:
@@ -217,7 +234,7 @@ class ModelHooks:
         """Called before ``loss.backward()``.
 
         Args:
-            loss: Loss divided by number of batches for gradient accumulation and scaled if using native AMP.
+            loss: Loss divided by number of batches for gradient accumulation and scaled if using AMP.
         """
         pass
 
@@ -229,13 +246,13 @@ class ModelHooks:
             Use the ``on_before_optimizer_step`` if you need the unscaled gradients.
         """
 
-    def on_before_optimizer_step(self, optimizer: Optimizer, optimizer_idx: int) -> None:
+    def on_before_optimizer_step(self, optimizer: Optimizer) -> None:
         """Called before ``optimizer.step()``.
 
         If using gradient accumulation, the hook is called once the gradients have been accumulated.
         See: :paramref:`~lightning.pytorch.trainer.Trainer.accumulate_grad_batches`.
 
-        If using native AMP, the loss will be unscaled before calling this hook.
+        If using AMP, the loss will be unscaled before calling this hook.
         See these `docs <https://pytorch.org/docs/stable/notes/amp_examples.html#working-with-unscaled-gradients>`__
         for more information on the scaling of gradients.
 
@@ -243,11 +260,10 @@ class ModelHooks:
 
         Args:
             optimizer: Current optimizer being used.
-            optimizer_idx: Index of the current optimizer being used.
 
         Example::
 
-            def on_before_optimizer_step(self, optimizer, optimizer_idx):
+            def on_before_optimizer_step(self, optimizer):
                 # example to inspect gradient information in tensorboard
                 if self.trainer.global_step % 25 == 0:  # don't make the tf file huge
                     for k, v in self.named_parameters():
@@ -372,11 +388,9 @@ class DataHooks:
         """
 
     def train_dataloader(self) -> TRAIN_DATALOADERS:
-        """Implement one or more PyTorch DataLoaders for training.
+        """An iterable or collection of iterables specifying training samples.
 
-        Return:
-            A collection of :class:`torch.utils.data.DataLoader` specifying training samples.
-            In the case of multiple dataloaders, please see this :ref:`section <multiple-dataloaders>`.
+        For more information about multiple dataloaders, see this :ref:`section <multiple-dataloaders>`.
 
         The dataloader you return will not be reloaded unless you set
         :paramref:`~lightning.pytorch.trainer.Trainer.reload_dataloaders_every_n_epochs` to
@@ -396,55 +410,15 @@ class DataHooks:
         - :meth:`setup`
 
         Note:
-            Lightning adds the correct sampler for distributed and arbitrary hardware.
+            Lightning tries to add the correct sampler for distributed and arbitrary hardware.
             There is no need to set it yourself.
-
-        Example::
-
-            # single dataloader
-            def train_dataloader(self):
-                transform = transforms.Compose([transforms.ToTensor(),
-                                                transforms.Normalize((0.5,), (1.0,))])
-                dataset = MNIST(root='/path/to/mnist/', train=True, transform=transform,
-                                download=True)
-                loader = torch.utils.data.DataLoader(
-                    dataset=dataset,
-                    batch_size=self.batch_size,
-                    shuffle=True
-                )
-                return loader
-
-            # multiple dataloaders, return as list
-            def train_dataloader(self):
-                mnist = MNIST(...)
-                cifar = CIFAR(...)
-                mnist_loader = torch.utils.data.DataLoader(
-                    dataset=mnist, batch_size=self.batch_size, shuffle=True
-                )
-                cifar_loader = torch.utils.data.DataLoader(
-                    dataset=cifar, batch_size=self.batch_size, shuffle=True
-                )
-                # each batch will be a list of tensors: [batch_mnist, batch_cifar]
-                return [mnist_loader, cifar_loader]
-
-            # multiple dataloader, return as dict
-            def train_dataloader(self):
-                mnist = MNIST(...)
-                cifar = CIFAR(...)
-                mnist_loader = torch.utils.data.DataLoader(
-                    dataset=mnist, batch_size=self.batch_size, shuffle=True
-                )
-                cifar_loader = torch.utils.data.DataLoader(
-                    dataset=cifar, batch_size=self.batch_size, shuffle=True
-                )
-                # each batch will be a dict of tensors: {'mnist': batch_mnist, 'cifar': batch_cifar}
-                return {'mnist': mnist_loader, 'cifar': cifar_loader}
         """
         raise MisconfigurationException("`train_dataloader` must be implemented to be used with the Lightning Trainer")
 
     def test_dataloader(self) -> EVAL_DATALOADERS:
-        r"""
-        Implement one or multiple PyTorch DataLoaders for testing.
+        r"""An iterable or collection of iterables specifying test samples.
+
+        For more information about multiple dataloaders, see this :ref:`section <multiple-dataloaders>`.
 
         For data processing use the following pattern:
 
@@ -461,44 +435,19 @@ class DataHooks:
         - :meth:`setup`
 
         Note:
-            Lightning adds the correct sampler for distributed and arbitrary hardware.
+            Lightning tries to add the correct sampler for distributed and arbitrary hardware.
             There is no need to set it yourself.
 
-        Return:
-            A :class:`torch.utils.data.DataLoader` or a sequence of them specifying testing samples.
-
-        Example::
-
-            def test_dataloader(self):
-                transform = transforms.Compose([transforms.ToTensor(),
-                                                transforms.Normalize((0.5,), (1.0,))])
-                dataset = MNIST(root='/path/to/mnist/', train=False, transform=transform,
-                                download=True)
-                loader = torch.utils.data.DataLoader(
-                    dataset=dataset,
-                    batch_size=self.batch_size,
-                    shuffle=False
-                )
-
-                return loader
-
-            # can also return multiple dataloaders
-            def test_dataloader(self):
-                return [loader_a, loader_b, ..., loader_n]
-
         Note:
             If you don't need a test dataset and a :meth:`test_step`, you don't need to implement
             this method.
-
-        Note:
-            In the case where you return multiple test dataloaders, the :meth:`test_step`
-            will have an argument ``dataloader_idx`` which matches the order here.
         """
         raise MisconfigurationException("`test_dataloader` must be implemented to be used with the Lightning Trainer")
 
     def val_dataloader(self) -> EVAL_DATALOADERS:
-        r"""
-        Implement one or multiple PyTorch DataLoaders for validation.
+        r"""An iterable or collection of iterables specifying validation samples.
+
+        For more information about multiple dataloaders, see this :ref:`section <multiple-dataloaders>`.
 
         The dataloader you return will not be reloaded unless you set
         :paramref:`~lightning.pytorch.trainer.Trainer.reload_dataloaders_every_n_epochs` to
@@ -512,44 +461,19 @@ class DataHooks:
         - :meth:`setup`
 
         Note:
-            Lightning adds the correct sampler for distributed and arbitrary hardware
+            Lightning tries to add the correct sampler for distributed and arbitrary hardware
             There is no need to set it yourself.
 
-        Return:
-            A :class:`torch.utils.data.DataLoader` or a sequence of them specifying validation samples.
-
-        Examples::
-
-            def val_dataloader(self):
-                transform = transforms.Compose([transforms.ToTensor(),
-                                                transforms.Normalize((0.5,), (1.0,))])
-                dataset = MNIST(root='/path/to/mnist/', train=False,
-                                transform=transform, download=True)
-                loader = torch.utils.data.DataLoader(
-                    dataset=dataset,
-                    batch_size=self.batch_size,
-                    shuffle=False
-                )
-
-                return loader
-
-            # can also return multiple dataloaders
-            def val_dataloader(self):
-                return [loader_a, loader_b, ..., loader_n]
-
         Note:
             If you don't need a validation dataset and a :meth:`validation_step`, you don't need to
             implement this method.
-
-        Note:
-            In the case where you return multiple validation dataloaders, the :meth:`validation_step`
-            will have an argument ``dataloader_idx`` which matches the order here.
         """
         raise MisconfigurationException("`val_dataloader` must be implemented to be used with the Lightning Trainer")
 
     def predict_dataloader(self) -> EVAL_DATALOADERS:
-        r"""
-        Implement one or multiple PyTorch DataLoaders for prediction.
+        r"""An iterable or collection of iterables specifying prediction samples.
+
+        For more information about multiple dataloaders, see this :ref:`section <multiple-dataloaders>`.
 
         It's recommended that all data downloads and preparation happen in :meth:`prepare_data`.
 
@@ -558,15 +482,11 @@ class DataHooks:
         - :meth:`setup`
 
         Note:
-            Lightning adds the correct sampler for distributed and arbitrary hardware
+            Lightning tries to add the correct sampler for distributed and arbitrary hardware
             There is no need to set it yourself.
 
         Return:
             A :class:`torch.utils.data.DataLoader` or a sequence of them specifying prediction samples.
-
-        Note:
-            In the case where you return multiple prediction dataloaders, the :meth:`predict_step`
-            will have an argument ``dataloader_idx`` which matches the order here.
         """
         raise MisconfigurationException(
             "`predict_dataloader` must be implemented to be used with the Lightning Trainer"
