@@ -11,12 +11,12 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from dataclasses import asdict, dataclass, replace
+from dataclasses import dataclass
 from functools import partial, wraps
 from typing import Any, Callable, cast, Dict, Generator, List, Optional, Tuple, Union
 
 import torch
-from lightning_utilities.core.apply_func import apply_to_collection, apply_to_collections
+from lightning_utilities.core.apply_func import apply_to_collection
 from torch import Tensor
 from torchmetrics import Metric
 from typing_extensions import TypedDict
@@ -25,18 +25,16 @@ from lightning.fabric.utilities import move_data_to_device
 from lightning.fabric.utilities.apply_func import convert_tensors_to_scalars
 from lightning.fabric.utilities.device_dtype_mixin import _DeviceDtypeModuleMixin
 from lightning.fabric.utilities.distributed import _distributed_available
+from lightning.fabric.utilities.imports import _TORCH_EQUAL_2_0, _TORCH_GREATER_EQUAL_2_0
 from lightning.pytorch.utilities.data import extract_batch_size
 from lightning.pytorch.utilities.exceptions import MisconfigurationException
-from lightning.pytorch.utilities.imports import _fault_tolerant_training
 from lightning.pytorch.utilities.memory import recursive_detach
 from lightning.pytorch.utilities.rank_zero import rank_zero_warn, WarningCache
 from lightning.pytorch.utilities.warnings import PossibleUserWarning
 
-_IN_METRIC = Union[Metric, Tensor]  # Do not include scalars as they were converted to tensors
-_OUT_METRIC = Union[Tensor, Dict[str, Tensor]]
-_PBAR_METRIC = Union[float, Dict[str, float]]
-_OUT_DICT = Dict[str, _OUT_METRIC]
-_PBAR_DICT = Dict[str, _PBAR_METRIC]
+_VALUE = Union[Metric, Tensor]  # Do not include scalars as they were converted to tensors
+_OUT_DICT = Dict[str, Tensor]
+_PBAR_DICT = Dict[str, float]
 
 
 class _METRICS(TypedDict):
@@ -113,7 +111,8 @@ class _Metadata:
     logger: bool = True
     on_step: bool = False
     on_epoch: bool = True
-    reduce_fx: Callable = torch.mean
+    # https://github.com/pytorch/pytorch/issues/96197
+    reduce_fx: Callable = "mean" if _TORCH_EQUAL_2_0 else torch.mean  # type: ignore[assignment]
     enable_graph: bool = False
     add_dataloader_idx: bool = True
     dataloader_idx: Optional[int] = None
@@ -181,27 +180,8 @@ class _Metadata:
     def is_custom_reduction(self) -> bool:
         return not (self.is_mean_reduction or self.is_max_reduction or self.is_min_reduction or self.is_sum_reduction)
 
-    def __getstate__(self) -> dict:
-        # drop the `sync.fn` to avoid potential pickle errors
-        # need to drop `fn` first otherwise `asdict` produces a `RecursionError`
-        copy = replace(self, _sync=replace(self.sync, fn=None))
-        d = asdict(copy)
-        # delete the `None` value so it does not override
-        del d["_sync"]["fn"]
-        return d
 
-    def __setstate__(self, state: dict, sync_fn: Optional[Callable] = None) -> None:
-        d = {**state, "_sync": _Sync(**state["_sync"], fn=sync_fn)}
-        self.__dict__.update(d)
-
-    @classmethod
-    def _reconstruct(cls, state: dict, sync_fn: Optional[Callable] = None) -> "_Metadata":
-        meta = cls(state["fx"], state["name"])
-        meta.__setstate__(state, sync_fn=sync_fn)
-        return meta
-
-
-class _ResultMetric(Metric, _DeviceDtypeModuleMixin):
+class _ResultMetric(Metric, _DeviceDtypeModuleMixin):  # type: ignore[misc]  # torchmetrics methods should return Self
     """Wraps the value provided to `:meth:`~lightning.pytorch.core.module.LightningModule.log`"""
 
     def __init__(self, metadata: _Metadata, is_tensor: bool) -> None:
@@ -224,7 +204,7 @@ class _ResultMetric(Metric, _DeviceDtypeModuleMixin):
         # this is defined here only because upstream is missing the type annotation
         self._forward_cache: Optional[Any] = None
 
-    def update(self, value: _IN_METRIC, batch_size: int) -> None:
+    def update(self, value: _VALUE, batch_size: int) -> None:
         if self.is_tensor:
             value = cast(Tensor, value)
             if not torch.is_floating_point(value):
@@ -273,7 +253,7 @@ class _ResultMetric(Metric, _DeviceDtypeModuleMixin):
             self.value.reset()
         self.has_reset = True
 
-    def forward(self, value: _IN_METRIC, batch_size: int) -> None:
+    def forward(self, value: _VALUE, batch_size: int) -> None:
         if self.meta.enable_graph:
             with torch.no_grad():
                 self.update(value, batch_size)
@@ -310,76 +290,17 @@ class _ResultMetric(Metric, _DeviceDtypeModuleMixin):
             state += f", cumulated_batch_size={self.cumulated_batch_size}"
         return f"{self.__class__.__name__}({state})"
 
-    def __getstate__(self, drop_value: bool = False) -> dict:
-        skip = ["update", "compute", "_update_signature", "_cache"]
-        if not self.is_tensor and drop_value:
-            # Avoid serializing ResultMetrics which are passed Metrics
-            skip.append("value")
-        d = {k: v for k, v in self.__dict__.items() if k not in skip}
-        d["meta"] = d["meta"].__getstate__()
-        d["_class"] = self.__class__.__name__
-        d["_is_synced"] = False  # don't consider the state as synced on reload
-        return d
-
-    def __setstate__(self, state: dict, sync_fn: Optional[Callable] = None) -> None:
-        d = {**state, "meta": _Metadata._reconstruct(state["meta"], sync_fn=sync_fn)}
-        super().__setstate__(d)
-
-    @classmethod
-    def _reconstruct(cls, state: dict, sync_fn: Optional[Callable] = None) -> "_ResultMetric":
-        # need to reconstruct twice because `meta` is used in `__init__`
-        meta = _Metadata._reconstruct(state["meta"])
-        result_metric = cls(meta, state["is_tensor"])
-        result_metric.__setstate__(state, sync_fn=sync_fn)
-        return result_metric
-
     def to(self, *args: Any, **kwargs: Any) -> "_ResultMetric":
-        self.__dict__.update(apply_to_collection(self.__dict__, (Tensor, Metric), move_data_to_device, *args, **kwargs))
+        d = self.__dict__
+        if _TORCH_GREATER_EQUAL_2_0:  # https://github.com/pytorch/pytorch/issues/96198
+            d = dict(d)
+        self.__dict__.update(apply_to_collection(d, (Tensor, Metric), move_data_to_device, *args, **kwargs))
         return self
 
 
-class _ResultMetricCollection(dict):
-    """Dict wrapper for easy access to metadata.
-
-    All of the leaf items should be instances of
-    :class:`~lightning.pytorch.trainer.connectors.logger_connector.result._ResultMetric`
-    with the same metadata.
-    """
-
-    @property
-    def meta(self) -> _Metadata:
-        return next(iter(self.values())).meta
-
-    @property
-    def has_tensor(self) -> bool:
-        return any(v.is_tensor for v in self.values())
-
-    def __getstate__(self, drop_value: bool = False) -> dict:
-        def getstate(item: _ResultMetric) -> dict:
-            return item.__getstate__(drop_value=drop_value)
-
-        items = apply_to_collection(dict(self), _ResultMetric, getstate)
-        return {"items": items, "meta": self.meta.__getstate__(), "_class": self.__class__.__name__}
-
-    def __setstate__(self, state: dict, sync_fn: Optional[Callable] = None) -> None:
-        # can't use `apply_to_collection` as it does not recurse items of the same type
-        items = {k: _ResultMetric._reconstruct(v, sync_fn=sync_fn) for k, v in state["items"].items()}
-        self.update(items)
-
-    @classmethod
-    def _reconstruct(cls, state: dict, sync_fn: Optional[Callable] = None) -> "_ResultMetricCollection":
-        rmc = cls()
-        rmc.__setstate__(state, sync_fn=sync_fn)
-        return rmc
-
-
-_METRIC_COLLECTION = Union[_IN_METRIC, _ResultMetricCollection]
-
-
 class _ResultCollection(dict):
-    """
-    Collection (dictionary) of :class:`~lightning.pytorch.trainer.connectors.logger_connector.result._ResultMetric` or
-    :class:`~lightning.pytorch.trainer.connectors.logger_connector.result._ResultMetricCollection`
+    """Collection (dictionary) of
+    :class:`~lightning.pytorch.trainer.connectors.logger_connector.result._ResultMetric`
 
     Example:
 
@@ -404,18 +325,9 @@ class _ResultCollection(dict):
 
     @property
     def result_metrics(self) -> List[_ResultMetric]:
-        o = []
+        return list(self.values())
 
-        def append_fn(v: _ResultMetric) -> None:
-            nonlocal o
-            o.append(v)
-
-        apply_to_collection(list(self.values()), _ResultMetric, append_fn)
-        return o
-
-    def _extract_batch_size(
-        self, value: Union[_ResultMetric, _ResultMetricCollection], batch_size: Optional[int], meta: _Metadata
-    ) -> int:
+    def _extract_batch_size(self, value: _ResultMetric, batch_size: Optional[int], meta: _Metadata) -> int:
         # check if we have extracted the batch size already
         if batch_size is None:
             batch_size = self.batch_size
@@ -424,8 +336,7 @@ class _ResultCollection(dict):
             return batch_size
 
         batch_size = 1
-        is_tensor = value.is_tensor if isinstance(value, _ResultMetric) else value.has_tensor
-        if self.batch is not None and is_tensor and meta.on_epoch and meta.is_mean_reduction:
+        if self.batch is not None and value.is_tensor and meta.on_epoch and meta.is_mean_reduction:
             batch_size = extract_batch_size(self.batch)
             self.batch_size = batch_size
 
@@ -435,12 +346,13 @@ class _ResultCollection(dict):
         self,
         fx: str,
         name: str,
-        value: _METRIC_COLLECTION,
+        value: _VALUE,
         prog_bar: bool = False,
         logger: bool = True,
         on_step: bool = False,
         on_epoch: bool = True,
-        reduce_fx: Callable = torch.mean,
+        # https://github.com/pytorch/pytorch/issues/96197
+        reduce_fx: Callable = "mean" if _TORCH_EQUAL_2_0 else torch.mean,  # type: ignore[assignment]
         enable_graph: bool = False,
         sync_dist: bool = False,
         sync_dist_fn: Callable = _Sync.no_op,
@@ -494,28 +406,19 @@ class _ResultCollection(dict):
         batch_size = self._extract_batch_size(self[key], batch_size, meta)
         self.update_metrics(key, value, batch_size)
 
-    def register_key(self, key: str, meta: _Metadata, value: _METRIC_COLLECTION) -> None:
+    def register_key(self, key: str, meta: _Metadata, value: _VALUE) -> None:
         """Create one _ResultMetric object per value.
 
         Value can be provided as a nested collection
         """
+        metric = _ResultMetric(meta, isinstance(value, Tensor)).to(self.device)
+        self[key] = metric
 
-        def fn(v: _IN_METRIC) -> _ResultMetric:
-            metric = _ResultMetric(meta, isinstance(v, Tensor))
-            return metric.to(self.device)
-
-        value = apply_to_collection(value, (Tensor, Metric), fn)
-        if isinstance(value, dict):
-            value = _ResultMetricCollection(value)
-        self[key] = value
-
-    def update_metrics(self, key: str, value: _METRIC_COLLECTION, batch_size: int) -> None:
-        def fn(result_metric: _ResultMetric, v: Tensor) -> None:
-            # performance: avoid calling `__call__` to avoid the checks in `torch.nn.Module._call_impl`
-            result_metric.forward(v.to(self.device), batch_size)
-            result_metric.has_reset = False
-
-        apply_to_collections(self[key], value, _ResultMetric, fn)
+    def update_metrics(self, key: str, value: _VALUE, batch_size: int) -> None:
+        result_metric = self[key]
+        # performance: avoid calling `__call__` to avoid the checks in `torch.nn.Module._call_impl`
+        result_metric.forward(value.to(self.device), batch_size)
+        result_metric.has_reset = False
 
     @staticmethod
     def _get_cache(result_metric: _ResultMetric, on_step: bool) -> Optional[Tensor]:
@@ -526,19 +429,12 @@ class _ResultCollection(dict):
             if result_metric._computed is None:
                 should = result_metric.meta.sync.should
                 if not should and _distributed_available() and result_metric.is_tensor:
-                    # ensure sync happens for FT since during a failure, the metrics are synced and saved to the
-                    # checkpoint, so during restart, metrics on rank 0 are from the accumulated ones from the previous
-                    # run, and on other ranks, they are 0. So we need to make sure they are synced in further training
-                    # to ensure correct calculation.
-                    if _fault_tolerant_training():
-                        result_metric.meta.sync.should = True
-                    else:
-                        warning_cache.warn(
-                            f"It is recommended to use `self.log({result_metric.meta.name!r}, ..., sync_dist=True)`"
-                            " when logging on epoch level in distributed setting to accumulate the metric across"
-                            " devices.",
-                            category=PossibleUserWarning,
-                        )
+                    warning_cache.warn(
+                        f"It is recommended to use `self.log({result_metric.meta.name!r}, ..., sync_dist=True)`"
+                        " when logging on epoch level in distributed setting to accumulate the metric across"
+                        " devices.",
+                        category=PossibleUserWarning,
+                    )
                 result_metric.compute()
                 result_metric.meta.sync.should = should
 
@@ -557,11 +453,7 @@ class _ResultCollection(dict):
 
     def valid_items(self) -> Generator:
         """This function is used to iterate over current valid metrics."""
-        return (
-            (k, v)
-            for k, v in self.items()
-            if not (isinstance(v, _ResultMetric) and v.has_reset) and self.dataloader_idx == v.meta.dataloader_idx
-        )
+        return ((k, v) for k, v in self.items() if not v.has_reset and self.dataloader_idx == v.meta.dataloader_idx)
 
     def _forked_name(self, result_metric: _ResultMetric, on_step: bool) -> Tuple[str, str]:
         name = result_metric.meta.name
@@ -578,23 +470,9 @@ class _ResultCollection(dict):
         metrics = _METRICS(callback={}, log={}, pbar={})
 
         for _, result_metric in self.valid_items():
-
-            # extract forward_cache or computed from the _ResultMetric. ignore when the output is None
-            value = apply_to_collection(result_metric, _ResultMetric, self._get_cache, on_step, include_none=False)
-
-            # convert metric collection to dict container.
-            if isinstance(value, _ResultMetricCollection):
-                value = dict(value.items())
-
-            # check if the collection is empty
-            has_tensor = False
-
-            def any_tensor(_: Any) -> None:
-                nonlocal has_tensor
-                has_tensor = True
-
-            apply_to_collection(value, Tensor, any_tensor)
-            if not has_tensor:
+            # extract forward_cache or computed from the _ResultMetric
+            value = self._get_cache(result_metric, on_step)
+            if not isinstance(value, Tensor):
                 continue
 
             name, forked_name = self._forked_name(result_metric, on_step)
@@ -623,15 +501,12 @@ class _ResultCollection(dict):
                 if ``None``, both are.
             fx: Function to reset
         """
-
-        def fn(item: _ResultMetric) -> None:
+        for item in self.values():
             requested_type = metrics is None or metrics ^ item.is_tensor
             same_fx = fx is None or fx == item.meta.fx
             if requested_type and same_fx:
                 item.reset()
 
-        apply_to_collection(self, _ResultMetric, fn)
-
     def to(self, *args: Any, **kwargs: Any) -> "_ResultCollection":
         """Move all data to the given device."""
         self.update(apply_to_collection(dict(self), (Tensor, Metric), move_data_to_device, *args, **kwargs))
@@ -644,16 +519,6 @@ class _ResultCollection(dict):
         """Move all data to CPU."""
         return self.to(device="cpu")
 
-    def sync(self) -> None:
-        for result_metric in self.result_metrics:
-            if result_metric.is_tensor and not result_metric._is_synced:
-                result_metric.sync(should_sync=not result_metric.meta.sync.rank_zero_only)
-
-    def unsync(self) -> None:
-        for result_metric in self.result_metrics:
-            if result_metric.is_tensor and result_metric._is_synced:
-                result_metric.unsync()
-
     def __str__(self) -> str:
         # remove empty values
         self_str = str({k: v for k, v in self.items() if v})
@@ -661,55 +526,3 @@ class _ResultCollection(dict):
 
     def __repr__(self) -> str:
         return f"{{{self.training}, {repr(self.device)}, {super().__repr__()}}}"
-
-    def __getstate__(self, drop_value: bool = True) -> dict:
-        d = self.__dict__.copy()
-        # all the items should be either `_ResultMetric`s or `_ResultMetricCollection`s
-        items = {k: v.__getstate__(drop_value=drop_value) for k, v in self.items()}
-        return {**d, "items": items}
-
-    def __setstate__(
-        self, state: dict, map_location: Optional[Union[str, torch.device]] = None, sync_fn: Optional[Callable] = None
-    ) -> None:
-        self.__dict__.update({k: v for k, v in state.items() if k != "items"})
-
-        def setstate(k: str, item: dict) -> Union[_ResultMetric, _ResultMetricCollection]:
-            if not isinstance(item, dict):
-                raise ValueError(f"Unexpected value: {item}")
-            cls = item["_class"]
-            if cls == _ResultMetric.__name__:
-                cls = _ResultMetric
-            elif cls == _ResultMetricCollection.__name__:
-                cls = _ResultMetricCollection
-            else:
-                raise ValueError(f"Unexpected class name: {cls}")
-            _sync_fn = sync_fn or (self[k].meta.sync.fn if k in self else None)
-            return cls._reconstruct(item, sync_fn=_sync_fn)
-
-        items = {k: setstate(k, v) for k, v in state["items"].items()}
-        self.update(items)
-
-        device = map_location or self.device
-        self.to(device)
-
-    def state_dict(self, drop_value: bool = True) -> dict:
-        return self.__getstate__(drop_value)
-
-    def load_state_dict(
-        self,
-        state_dict: dict,
-        map_location: Optional[Union[str, torch.device]] = None,
-        sync_fn: Optional[Callable] = None,
-        metrics: Optional[Dict[str, Metric]] = None,
-    ) -> None:
-        self.__setstate__(state_dict, map_location=map_location, sync_fn=sync_fn)
-
-        if not metrics:
-            return
-
-        # iterate through result metrics and re-attached Metric references on reload.
-        result_metrics = self.result_metrics
-        for metric_attribute, metric in metrics.items():
-            for result_metric in result_metrics:
-                if result_metric.meta.metric_attribute == metric_attribute:
-                    result_metric.value = metric
