@@ -18,71 +18,14 @@ import inspect
 import pickle
 import types
 from dataclasses import fields, is_dataclass
-from typing import Any, Dict, List, MutableMapping, Optional, Sequence, Tuple, Type, Union
+from typing import Any, Dict, List, Literal, MutableMapping, Optional, Sequence, Tuple, Type, Union
 
 from torch import nn
-from typing_extensions import Literal
 
 import lightning.pytorch as pl
 from lightning.pytorch.utilities.rank_zero import rank_zero_warn
 
 
-def str_to_bool_or_str(val: str) -> Union[str, bool]:
-    """Possibly convert a string representation of truth to bool. Returns the input otherwise. Based on the python
-    implementation distutils.utils.strtobool.
-
-    True values are 'y', 'yes', 't', 'true', 'on', and '1'; false values are 'n', 'no', 'f', 'false', 'off', and '0'.
-    """
-    lower = val.lower()
-    if lower in ("y", "yes", "t", "true", "on", "1"):
-        return True
-    if lower in ("n", "no", "f", "false", "off", "0"):
-        return False
-    return val
-
-
-def str_to_bool(val: str) -> bool:
-    """Convert a string representation of truth to bool.
-
-    True values are 'y', 'yes', 't', 'true', 'on', and '1'; false values
-    are 'n', 'no', 'f', 'false', 'off', and '0'.
-
-    Raises:
-        ValueError:
-            If ``val`` isn't in one of the aforementioned true or false values.
-
-    >>> str_to_bool('YES')
-    True
-    >>> str_to_bool('FALSE')
-    False
-    """
-    val_converted = str_to_bool_or_str(val)
-    if isinstance(val_converted, bool):
-        return val_converted
-    raise ValueError(f"invalid truth value {val_converted}")
-
-
-def str_to_bool_or_int(val: str) -> Union[bool, int, str]:
-    """Convert a string representation to truth of bool if possible, or otherwise try to convert it to an int.
-
-    >>> str_to_bool_or_int("FALSE")
-    False
-    >>> str_to_bool_or_int("1")
-    True
-    >>> str_to_bool_or_int("2")
-    2
-    >>> str_to_bool_or_int("abc")
-    'abc'
-    """
-    val_converted = str_to_bool_or_str(val)
-    if isinstance(val_converted, bool):
-        return val_converted
-    try:
-        return int(val_converted)
-    except ValueError:
-        return val_converted
-
-
 def is_picklable(obj: object) -> bool:
     """Tests if an object can be pickled."""
 
@@ -102,14 +45,12 @@ def clean_namespace(hparams: MutableMapping) -> None:
         del hparams[k]
 
 
-def parse_class_init_keys(
-    cls: Union[Type["pl.LightningModule"], Type["pl.LightningDataModule"]]
-) -> Tuple[str, Optional[str], Optional[str]]:
+def parse_class_init_keys(cls: Type) -> Tuple[str, Optional[str], Optional[str]]:
     """Parse key words for standard ``self``, ``*args`` and ``**kwargs``.
 
     Examples:
 
-        >>> class Model():
+        >>> class Model:
         ...     def __init__(self, hparams, *my_args, anykw=42, **my_kwargs):
         ...         pass
         >>> parse_class_init_keys(Model)
@@ -196,19 +137,6 @@ def collect_init_args(
     return path_args
 
 
-def flatten_dict(source: Dict[str, Any], result: Optional[Dict[str, Any]] = None) -> Dict[str, Any]:
-    if result is None:
-        result = {}
-
-    for k, v in source.items():
-        if isinstance(v, dict):
-            _ = flatten_dict(v, result)
-        else:
-            result[k] = v
-
-    return result
-
-
 def save_hyperparameters(
     obj: Any, *args: Any, ignore: Optional[Union[Sequence[str], str]] = None, frame: Optional[types.FrameType] = None
 ) -> None:
